# tket2-exts

[![pypi][]](https://pypi.org/project/tket2-exts/)
[![codecov][]](https://codecov.io/gh/CQCL/tket2)
[![py-version][]](https://pypi.org/project/tket2-exts/)

  [codecov]: https://img.shields.io/codecov/c/gh/CQCL/tket2?logo=codecov
  [py-version]: https://img.shields.io/pypi/pyversions/tket2-exts
  [pypi]: https://img.shields.io/pypi/v/tket2-exts

This is an auxiliary Python package containing HUGR extension definitions for `tket2`
operations and types.

This package is intended to be used as an internal dependency for `tket2`.
See <https://pypi.org/project/tket2/> for the main package.

## Install

TKET2-exts can be installed via `pip`.

```sh
pip install tket2_exts
```

## Development

See [DEVELOPMENT.md] information on how to develop and contribute to this package.

  [DEVELOPMENT.md]: https://github.com/CQCL/tket2/blob/main/DEVELOPMENT.md

## License

This project is licensed under Apache License, Version 2.0 ([LICENCE][] or <http://www.apache.org/licenses/LICENSE-2.0>).

  [LICENCE]: https://github.com/CQCL/tket2/blob/main/LICENCE
